@@ -20,7 +20,7 @@ use OAuth::Cmdline::GoogleDrive;
 
 use Net::Google::Drive::Simple::Item;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 ###########################################
 sub new {
@@ -725,10 +725,12 @@ Net::Google::Drive::Simple - Simple modification of Google Drive data
         # item is a Net::Google::Drive::Simple::Item object
 
         if ( $item->is_folder ) {
-             say "** ", $child->title, " is a folder";
+            say "** ", $item->title, " is a folder";
         } else {
-             say $item->title, " is a file " . $child->mimeType;
-             say $item->originalFilename(), " can be downloaded at ", $child->downloadUrl();
+            say $item->title, " is a file ", $item->mimeType;
+            eval { # originalFilename not necessary available for all files
+              say $item->originalFilename(), " can be downloaded at ", $item->downloadUrl();
+            };
         }
     }
 
